@@ -1,20 +1,20 @@
-#' HERE Routing API: Isoline
+#' HERE Routing API: Calculate Isoline
 #'
-#' Calcuates isolines (\code{POLYGON} or \code{MULTIPOLYGON}) that connect the end points of all routes
-#' leaving from defined centers (POIs) with either a specified length, a
-#' specified travel time or consumption.
+#' Calcuates isolines (\code{POLYGON} or \code{MULTIPOLYGON}) using the HERE 'Routing' API
+#' that connect the end points of all routes leaving from defined centers (POIs) with either
+#' a specified length, a specified travel time or consumption.
 #'
 #' @references
 #' \href{https://developer.here.com/documentation/routing/topics/resource-calculate-isoline.html}{HERE Routing API: Calculate Isoline}
 #'
 #' @param poi \code{sf} object, Points of Interest (POIs) of geometry type \code{POINT}.
+#' @param datetime \code{POSIXct} object, datetime for the departure (or arrival if \code{arrival = TRUE}).
+#' @param arrival boolean, are the provided Points of Interest (POIs) the origin or destination locations (\code{default = FALSE})?
 #' @param range numeric, a vector of type \code{integer} containing the breaks for the generation of the isolines: (1) time in seconds; (2) distance in meters; (3) consumption in costfactor.
-#' @param rangetype character, unit of the isolines: \code{"distance"}, \code{"time"} or \code{"consumption"}.
+#' @param range_type character, unit of the isolines: \code{"distance"}, \code{"time"} or \code{"consumption"}.
 #' @param type character, set the routing type: \code{"fastest"} or \code{"shortest"}.
 #' @param mode character, set the transport mode: \code{"car"}, \code{"pedestrian"} or \code{"truck"}.
-#' @param traffic boolean, use real-time traffic or prediction in routing (\code{default = FALSE})? If no \code{departure} date and time is set, the current timestamp at the moment of the request is used for \code{departure}.
-#' @param departure datetime, timestamp of type \code{POSIXct}, \code{POSIXt} for the departure.
-#' @param start boolean, are the provided Points of Interest (POIs) the start or destination (\code{default = TRUE})?
+#' @param traffic boolean, use real-time traffic or prediction in routing (\code{default = FALSE})? If no \code{datetime} is set, the current timestamp at the moment of the request is used for \code{datetime}.
 #' @param aggregate boolean, aggregate (with function \code{min}) and intersect the isolines from geometry type \code{POLYGON} to geometry type \code{MULTIPOLYGON} (\code{default = TRUE})?
 #' @param url_only boolean, only return the generated URLs (\code{default = FALSE})?
 #'
@@ -23,11 +23,8 @@
 #' @export
 #'
 #' @examples
-#' # Authentication
-#' set_auth(
-#'   app_id = "<YOUR APP ID>",
-#'   app_code = "<YOUR APP CODE>"
-#' )
+#' # Provide an API Key for a HERE project
+#' set_key("<YOUR API KEY>")
 #'
 #' # Isochrone for 5, 10, 15, 20, 25 and 30 minutes driving time
 #' isolines <- isoline(
@@ -35,25 +32,25 @@
 #'   range = seq(5, 30, 5) * 60,
 #'   url_only = TRUE
 #' )
-isoline <- function(poi, range = seq(5, 30, 5) * 60, rangetype = "time",
+isoline <- function(poi, datetime = Sys.time(), arrival = FALSE,
+                    range = seq(5, 30, 5) * 60, range_type = "time",
                     type = "fastest", mode = "car", traffic = FALSE,
-                    departure = NULL, start = TRUE, aggregate = TRUE,
-                    url_only = FALSE) {
+                    aggregate = TRUE, url_only = FALSE) {
 
   # Checks
   .check_points(poi)
-  .check_datetime(departure)
-  .check_rangetype(rangetype)
+  .check_datetime(datetime)
+  .check_range_type(range_type)
   .check_type(type = type, request = "calculateisoline")
   .check_mode(mode = mode, request = "calculateisoline")
   .check_boolean(traffic)
-  .check_boolean(start)
+  .check_boolean(arrival)
   .check_boolean(aggregate)
   .check_boolean(url_only)
 
-  # Add authentication
-  url <- .add_auth(
-    url = "https://isoline.route.api.here.com/routing/7.2/calculateisoline.json?"
+  # Add API key
+  url <- .add_key(
+    url = "https://isoline.route.ls.hereapi.com/routing/7.2/calculateisoline.json?"
   )
 
   # Add point coords
@@ -65,21 +62,21 @@ isoline <- function(poi, range = seq(5, 30, 5) * 60, rangetype = "time",
   )
   url = paste0(
     url,
-    if (start) {"&start="} else {"&destination="},
+    if (!arrival) {"&start="} else {"&destination="},
     poi
   )
 
-  # Add range and rangetype
+  # Add range and range type
   url = paste0(
     url,
     "&range=",
     paste0(range, collapse = ","),
     "&rangetype=",
-    rangetype
+    range_type
   )
 
   # Add consumption details
-  if (rangetype == "consumption") {
+  if (range_type == "consumption") {
     url <- paste0(
       url,
       "&consumptionmodel=",
@@ -99,8 +96,8 @@ isoline <- function(poi, range = seq(5, 30, 5) * 60, rangetype = "time",
   # Add departure time
   url <- .add_datetime(
     url,
-    departure,
-    "departure"
+    datetime,
+    if (arrival) "arrival" else "departure"
   )
 
   # Return urls if chosen
@@ -116,7 +113,7 @@ isoline <- function(poi, range = seq(5, 30, 5) * 60, rangetype = "time",
   ids <- .get_ids(data)
   count <- 0
   isolines <-  sf::st_as_sf(
-    data.table::rbindlist(
+    as.data.frame(data.table::rbindlist(
       lapply(data, function(con) {
         count <<- count + 1
         df <- jsonlite::fromJSON(con)
@@ -126,21 +123,21 @@ isoline <- function(poi, range = seq(5, 30, 5) * 60, rangetype = "time",
         sf::st_as_sf(
           data.table::data.table(
             id = ids[count],
-            timestamp = as.POSIXct(df$response$metaInfo$timestamp,
-                                   tz = "UTC",
-                                   format = "%Y-%m-%dT%H:%M:%SZ"),
-            range = df$response$isoline$range,
+            departure = if(arrival) (datetime - df$response$isoline$range) else datetime,
+            arrival = if(arrival) datetime else (datetime + df$response$isoline$range),
+            range =  df$response$isoline$range,
             lng = df$response$center$longitude,
             lat = df$response$center$latitude
           ),
           geometry = sf::st_as_sfc(geometry, crs = 4326)
         )
       })
-    )
+    ))
   )
 
   # Aggregate
   if (aggregate) {
+    tz <- attr(isolines$departure, "tzone")
     isolines <- sf::st_set_precision(isolines, 1e4)
     isolines <- lwgeom::st_make_valid(isolines)
     isolines <- stats::aggregate(isolines, by = list(isolines$range),
@@ -150,6 +147,8 @@ isoline <- function(poi, range = seq(5, 30, 5) * 60, rangetype = "time",
     isolines <- sf::st_difference(isolines)
     isolines$Group.1 <- NULL
     isolines$id <- NA
+    attr(isolines$departure, "tzone") <- tz
+    attr(isolines$arrival, "tzone") <- tz
 
     # Fix geometry collections
     suppressWarnings(
@@ -158,6 +157,7 @@ isoline <- function(poi, range = seq(5, 30, 5) * 60, rangetype = "time",
       )
     )
   }
+
   rownames(isolines) <- NULL
   return(isolines)
 }
